=== modified file '.bzrignore'
--- .bzrignore	2009-02-26 19:51:30 +0000
+++ .bzrignore	2009-03-02 23:14:32 +0000
@@ -258,3 +258,4 @@
 virtual_column_info.gcno
 xid.gcno
 *.orig
+m4/bzr_version.m4

=== modified file 'config/autorun.sh'
--- config/autorun.sh	2009-01-01 00:35:09 +0000
+++ config/autorun.sh	2009-03-03 01:59:57 +0000
@@ -29,6 +29,26 @@
 
 if test -d ".bzr" ; then
   bzr log --short > ChangeLog || touch ChangeLog
+  BZR_REVNO=`bzr revno`
+  BZR_REVID=`bzr log -r-1 --show-ids | grep revision-id | awk '{print $2}' | head -1`
+  BZR_BRANCH=`bzr nick`
+  RELEASE_DATE=`date +%Y.%m`
+  RELEASE_VERSION="${RELEASE_DATE}.${BZR_REVNO}"
+  if test "x${BZR_BRANCH}" != "xdrizzle" ; then
+    RELEASE_VERSION="${RELEASE_VERSION}-${BZR_BRANCH}"
+  fi
+  sed -e "s/@BZR_REVNO@/${BZR_REVNO}/" \
+      -e "s/@BZR_REVID@/${BZR_REVID}/" \
+      -e "s/@BZR_BRANCH@/${BZR_BRANCH}/" \
+      -e "s/@RELEASE_DATE@/${RELEASE_DATE}/" \
+      -e "s/@RELEASE_VERSION@/${RELEASE_VERSION}/" \
+    m4/bzr_version.m4.in > m4/bzr_version.m4.new
+
+  if ! diff m4/bzr_version.m4.new m4/bzr_version.m4 >/dev/null 2>&1 ; then
+    mv m4/bzr_version.m4.new m4/bzr_version.m4
+  else
+    rm m4/bzr_version.m4.new
+  fi
 else
   touch ChangeLog
 fi

=== modified file 'configure.ac'
--- configure.ac	2009-02-26 20:57:39 +0000
+++ configure.ac	2009-03-03 08:08:10 +0000
@@ -3,10 +3,12 @@
 
 AC_PREREQ(2.59)dnl		Minimum Autoconf version required.
 
-AC_INIT([drizzle],[7.0.0],[http://bugs.launchpad.net/drizzle])
+m4_include(m4/bzr_version.m4)
+
 AC_CONFIG_SRCDIR([drizzled/drizzled.cc])
 AC_CONFIG_AUX_DIR(config)
 AC_CONFIG_HEADERS([config.h])
+AC_CONFIG_MACRO_DIR([m4])
 
 # Setting CFLAGS here prevents AC_CANONICAL_TARGET from injecting them
 SAVE_CFLAGS=${CFLAGS}
@@ -80,15 +82,6 @@
 # The port should be constant for a LONG time
 DRIZZLE_TCP_PORT_DEFAULT=4427
 
-# We need to hack in some of the non-standard locations that solaris sticks
-# stuff in. This makes me very sad.
-case "$host_os" in
-  solaris*)
-    CPPFLAGS="${CPPFLAGS} -I/opt/csw/include -I/opt/local/include"
-    LDFLAGS="${LDFLAGS} -L/opt/csw/lib -L/opt/csw/lib"
-    ;;
-esac
-
 m4_include(m4/dtrace.m4)
 
 m4_include(m4/character_sets.m4)
@@ -119,7 +112,7 @@
     [SYSTEM_TYPE="$host_vendor-$host_os"])
 AC_ARG_WITH([machine-type],
     [AS_HELP_STRING([--with-machine-type],
-       [Set the machine type, like "powerpc"])],
+       [Set the machine type, like "sparc"])],
     [MACHINE_TYPE="$withval"],
     [MACHINE_TYPE="$host_cpu"])
 AC_SUBST(SYSTEM_TYPE)
@@ -234,8 +227,8 @@
 then
   case "$host_cpu" in
     *ppc* | *powerpc*)
-      AM_CFLAGS="$AM_CFLAGS -mno-fused-madd"
-      AM_CXXFLAGS="$AM_CXXFLAGS -mno-fused-madd"
+      CFLAGS="$CFLAGS -mno-fused-madd"
+      CXXFLAGS="$CXXFLAGS -mno-fused-madd"
     ;;
   esac
 fi
@@ -243,8 +236,8 @@
 # First check for gcc and g++
 if test "$GCC" = "yes"
 then
-  AM_CFLAGS="${AM_CPPFLAGS} -ggdb3 -std=gnu99"
-  AM_CXXFLAGS="${AM_CXXFLAGS} -ggdb3 -std=gnu++98"
+  CFLAGS="${CFLAGS} -ggdb3 -std=gnu99"
+  CXXFLAGS="${CXXFLAGS} -ggdb3 -std=gnu++98"
 
   DEBUG_CFLAGS="-O0"
   DEBUG_CXXFLAGS="-O0"
@@ -254,18 +247,32 @@
 fi
 if test "$SUNCC" = "yes"
 then
+  isainfo_k=`isainfo -k`
   if test "$target_cpu" = "sparc"
   then
     MEMALIGN_FLAGS="-xmemalign=8s"
+    IS_64="-m64"
+    LDFLAGS="${LDFLAGS} -L/usr/lib/${isainfo_k} -L/usr/local/lib/${isainfo_k}"
+  else
+    if test "$isainfo_k" = "amd64"
+    then
+      IS_64="-m64"
+      LDFLAGS="${LDFLAGS} -L/usr/lib/${isainfo_k} -L/usr/local/lib/${isainfo_k}"
+    fi
   fi
-  AM_CXXFLAGS="${AM_CXXFLAGS} -xlang=c99 -g -compat=5 -library=stlport4 -template=no%extdef ${MEMALIGN_FLAGS}"
-  AM_CFLAGS="${AM_CFLAGS} -g ${MEMALIGN_FLAGS}"
+  CPPFLAGS="${CPPFLAGS} -I/usr/local/include"
+
+  CXXFLAGS="${CXXFLAGS} -xlang=c99 -g -mt -compat=5 -library=stlport4 -template=no%extdef ${IS_64} ${MEMALIGN_FLAGS}"
+  CFLAGS="${CFLAGS} -g -mt -xc99=all ${IS_64} ${MEMALIGN_FLAGS}"
   DEBUG_CFLAGS="-xO0"
   DEBUG_CXXFLAGS="-xO0" 
 
-  OPTIMIZE_FLAGS="-xO4 -xlibmil -xdepend -xprefetch=explicit"
+  dnl TODO: -xO4 causes a Sun Studio failure in innodb... let's check back
+  dnl       in on this one.
+  OPTIMIZE_FLAGS="-xO3 -xlibmil -xdepend"
   OPTIMIZE_CFLAGS="${OPTIMIZE_FLAGS} -Xa -xstrconst"
   OPTIMIZE_CXXFLAGS="${OPTIMIZE_FLAGS}"
+
 fi
 
 # We use libtool
@@ -296,12 +303,12 @@
 if test "$with_debug" = "yes"
 then
   # Debuging. No optimization.
-  AM_CFLAGS="${DEBUG_CFLAGS} -DDEBUG ${AM_CFLAGS}"
-  AM_CXXFLAGS="${DEBUG_CXXFLAGS} -DDEBUG ${AM_CXXFLAGS}"
+  CFLAGS="${DEBUG_CFLAGS} -DDEBUG ${CFLAGS}"
+  CXXFLAGS="${DEBUG_CXXFLAGS} -DDEBUG ${CXXFLAGS}"
 else
   # Optimized version. No debug
-  AM_CFLAGS="${OPTIMIZE_CFLAGS} ${AM_CFLAGS}"
-  AM_CXXFLAGS="$OPTIMIZE_CXXFLAGS ${AM_CXXFLAGS}"
+  CFLAGS="${OPTIMIZE_CFLAGS} ${CFLAGS}"
+  CXXFLAGS="${OPTIMIZE_CXXFLAGS} ${CXXFLAGS}"
 fi
 
 
@@ -395,7 +402,7 @@
 
 ACX_PTHREAD(,AC_MSG_ERROR(could not find libpthread))
 LIBS="$PTHREAD_LIBS $LIBS"
-AM_CFLAGS="${AM_CFLAGS} $PTHREAD_CFLAGS"
+CFLAGS="${CFLAGS} ${PTHREAD_CFLAGS}"
 CC="$PTHREAD_CC"
 
 #--------------------------------------------------------------------
@@ -1336,16 +1343,16 @@
   NO_REDUNDANT_DECLS="-Wno-redundant-decls"
   # Disable exceptions as they seams to create problems with gcc and threads.
   # drizzled doesn't use run-time-type-checking, so we disable it.
-  AM_CXXFLAGS="${AM_CXXFLAGS} -fno-rtti"
-  AM_CPPFLAGS="${AM_CPPFLAGS} -fpch-deps"
+  CXXFLAGS="${CXXFLAGS} -fno-rtti"
+  CPPFLAGS="${CPPFLAGS} -fpch-deps"
   PROTOSKIP_WARNINGS="${NO_SHADOW}"
 fi
 if test "$SUNCC" = "yes"
 then
   if test "$ac_datarace" = "yes"
   then
-    AM_CFLAGS="${AM_CFLAGS} -xinstrument=datarace"
-    AM_CXXFLAGS="${AM_CXXFLAGS} -xinstrument=datarace"
+    CFLAGS="${CFLAGS} -xinstrument=datarace"
+    CXXFLAGS="${CXXFLAGS} -xinstrument=datarace"
   fi
 
   if test "$ac_warn_fail" = "yes"
@@ -1353,11 +1360,9 @@
     W_FAIL="-errwarn=%all"
   fi
 
-  CC_WARNINGS="-v -xc99=all -errtags=yes -erroff=E_ATTRIBUTE_NOT_VAR"
-  CXX_WARNINGS="+w +w2 -xport64 -errtags=yes -erroff=attrskipunsup,doubunder,reftotemp,inllargeuse -compat=5"
-  #CC_WARNINGS="-v -xc99=all -errtags=yes -erroff=E_ATTRIBUTE_NOT_VAR"
-  #CXX_WARNINGS="+w +w2 -xport64 -errtags=yes -erroff=attrskipunsup,doubunder -compat=5"
-  PROTOSKIP_WARNINGS="-erroff=attrskipunsup,doubunder,reftotemp,wbadinitl,identexpected,inllargeuse"
+  CC_WARNINGS="-v -errtags=yes -erroff=E_ATTRIBUTE_NOT_VAR ${W_FAIL}"
+  CXX_WARNINGS="+w +w2 -xport64 -errtags=yes -erroff=attrskipunsup,doubunder,reftotemp,inllargeuse,truncwarn1,signextwarn ${W_FAIL}" 
+  PROTOSKIP_WARNINGS="-erroff=attrskipunsup,doubunder,reftotemp,wbadinitl,identexpected,inllargeuse,truncwarn1,signextwarn"
   NO_UNREACHED="-erroff=E_STATEMENT_NOT_REACHED"
   if test "$ac_exceptions" = "no"
   then
@@ -1365,9 +1370,6 @@
     W_EXCEPTIONS="-features=except"
   fi
 fi
-AM_CXXFLAGS="${CXX_WARNINGS} ${NO_EXCEPTIONS}  ${AM_CXXFLAGS}"
-AM_CFLAGS="${CC_WARNINGS} ${AM_CFLAGS}"
-
 AC_SUBST(NO_EXCEPTIONS)
 AC_SUBST(W_EXCEPTIONS)
 AC_SUBST(NO_SHADOW)
@@ -1376,32 +1378,24 @@
 AC_SUBST(PROTOSKIP_WARNINGS)
 AC_SUBST(NO_UNREACHED)
 
-GLOBAL_CPPFLAGS='-I$(top_srcdir) -I$(top_builddir)'
 if test "$ac_cv_func_timegm" = "no" -o "$gl_cv_func_gnu_getopt" = "no"
 then
-  GLOBAL_CPPFLAGS="${GLOBAL_CPPFLAGS} -I\$(top_srcdir)/gnulib -I\$(top_builddir)/gnulib"
+  CPPFLAGS="-I\$(top_srcdir)/gnulib -I\$(top_builddir)/gnulib ${CPPFLAGS}"
 fi
-AC_SUBST([GLOBAL_CPPFLAGS])
-AC_SUBST([AM_CPPFLAGS],['${GLOBAL_CPPFLAGS}'])
-AC_SUBST([GLOBAL_CXXFLAGS],[${AM_CXXFLAGS}])
+CPPFLAGS="-I\$(top_srcdir) -I\$(top_builddir) ${CPPFLAGS}"
+
+AM_CPPFLAGS="${CPPFLAGS}"
+AM_CFLAGS="${CC_WARNINGS} ${CFLAGS}"
+AM_CXXFLAGS="${CXX_WARNINGS} ${NO_EXCEPTIONS} ${CXXFLAGS}"
+
+AC_SUBST([AM_CPPFLAGS])
 AC_SUBST([AM_CFLAGS])
 AC_SUBST([AM_CXXFLAGS])
 
-
-# Some usefull subst
-AC_SUBST(CC)
-AC_SUBST(GXX)
-
-# Set configuration options for make_binary_distribution
-case $SYSTEM_TYPE in
-  *netware*)
-    MAKE_BINARY_DISTRIBUTION_OPTIONS="$MAKE_BINARY_DISTRIBUTION_OPTIONS --no-strip"
-    ;;
-  *)
-    : # no change for other platforms yet
-    ;;
-esac
-AC_SUBST(MAKE_BINARY_DISTRIBUTION_OPTIONS)
+dnl We've collected the flags in AM_*FLAGS now, so blank these.
+CFLAGS=""
+CXXFLAGS=""
+CPPFLAGS=""
 
 AC_SUBST(pkgplugindir,"\$(pkglibdir)/plugin")
 
@@ -1489,3 +1483,6 @@
 echo "   * C++ cmath namespace:       $ac_cv_cxx_cmath_namespace"
 echo ""
 echo "---"
+
+dnl libtoolize scans configure.ac  and needs to see some text
+m4_define([LIBTOOLIZE_AC_INIT], [])

=== modified file 'drizzled/Makefile.am'
--- drizzled/Makefile.am	2009-02-28 17:49:22 +0000
+++ drizzled/Makefile.am	2009-03-03 01:59:29 +0000
@@ -271,6 +271,8 @@
 		plugin_logging.h \
 		plugin_parser.h \
 		plugin_qcache.h \
+		plugin_registry.h \
+		plugin_registry_impl.h \
 		plugin_replicator.h \
 		plugin_scheduling.h \
 		probes.h \
@@ -574,6 +576,8 @@
 		opt_range.cc \
 		opt_sum.cc \
 		parser.cc \
+		plugin_registry.cc \
+		plugin_registry_impl.cc \
 		protocol.cc \
 		qcache.cc \
 		query_id.cc \

=== modified file 'drizzled/drizzled.cc'
--- drizzled/drizzled.cc	2009-03-02 15:59:22 +0000
+++ drizzled/drizzled.cc	2009-03-03 08:32:10 +0000
@@ -468,7 +468,6 @@
 
 static void usage(void);
 static void clean_up_mutexes(void);
-static void drizzled_exit(int exit_code) __attribute__((noreturn));
 extern "C" bool safe_read_error_impl(NET *net);
 
 /****************************************************************************
@@ -620,12 +619,6 @@
   else if (opt_help)
     usage();
   clean_up(!opt_help && (exit_code)); /* purecov: inspected */
-  drizzled_exit(exit_code);
-}
-
-
-static void drizzled_exit(int exit_code)
-{
   clean_up_mutexes();
   my_end(opt_endinfo ? MY_CHECK_ERROR | MY_GIVE_INFO : 0);
   exit(exit_code); /* purecov: inspected */
@@ -759,8 +752,6 @@
       errmsg_printf(ERRMSG_LVL_ERROR, _("Fatal error: Please read \"Security\" section of "
                       "the manual to find out how to run drizzled as root!\n"));
     unireg_abort(1);
-
-    return NULL;
   }
   /* purecov: begin tested */
   if (!strcmp(user,"root"))
@@ -792,7 +783,11 @@
   }
 #endif
 
+/* Sun Studio 5.10 doesn't like this line.  5.9 requires it */
+#if defined(__SUNPRO_CC) && (__SUNPRO_CC <= 0x590)
   return NULL;
+#endif
+
 }
 
 static void set_user(const char *user, struct passwd *user_info_arg)
@@ -1696,10 +1691,10 @@
     }
     if (!ha_storage_engine_is_enabled(hton))
     {
-          errmsg_printf(ERRMSG_LVL_ERROR, _("Default storage engine (%s) is not available"),
-                      default_storage_engine_str);
+      errmsg_printf(ERRMSG_LVL_ERROR, _("Default storage engine (%s) is not available"),
+                    default_storage_engine_str);
       unireg_abort(1);
-      assert(global_system_variables.table_plugin);
+      //assert(global_system_variables.table_plugin);
     }
     else
     {
@@ -1880,7 +1875,9 @@
   (void) pthread_mutex_unlock(&LOCK_thread_count);
 
   clean_up(1);
-  drizzled_exit(0);
+  clean_up_mutexes();
+  my_end(opt_endinfo ? MY_CHECK_ERROR | MY_GIVE_INFO : 0);
+  return 0;
 }
 
 

=== modified file 'drizzled/field.cc'
--- drizzled/field.cc	2009-02-28 17:48:22 +0000
+++ drizzled/field.cc	2009-03-03 09:40:55 +0000
@@ -1473,7 +1473,6 @@
     case Item::PARAM_ITEM:
          my_error(ER_VIRTUAL_COLUMN_FUNCTION_IS_NOT_ALLOWED, MYF(0), field_name);
          return true;
-         break;
     default:
       // Continue with the field creation
       break;
@@ -1702,7 +1701,7 @@
   case DRIZZLE_TYPE_BLOB:		return 4+portable_sizeof_char_ptr;
   case DRIZZLE_TYPE_ENUM:
   case DRIZZLE_TYPE_NEWDECIMAL:
-    abort(); return 0;                          // This shouldn't happen
+    abort();
   default:
     return 0;
   }

=== modified file 'drizzled/plugin.h'
--- drizzled/plugin.h	2009-02-27 22:01:00 +0000
+++ drizzled/plugin.h	2009-03-01 06:50:06 +0000
@@ -389,6 +389,27 @@
 struct handlerton;
 
 
+class Plugin
+{
+private:
+  std::string name;
+  std::string version;
+  std::string author;
+  std::string description;
+
+public:
+  Plugin(std::string in_name, std::string in_version,
+         std::string in_author, std::string in_description)
+    : name(in_name), version(in_version),
+    author(in_author), description(in_description)
+  {}
+
+  virtual ~Plugin() {}
+
+  virtual void add_functions() {}
+
+};
+
 /*************************************************************************
   st_mysql_value struct for reading values from mysqld.
   Used by server variables framework to parse user-provided values.

=== added file 'drizzled/plugin_registry.cc'
--- drizzled/plugin_registry.cc	1970-01-01 00:00:00 +0000
+++ drizzled/plugin_registry.cc	2009-03-03 02:22:51 +0000
@@ -0,0 +1,57 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2008 Sun Microsystems
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "drizzled/server_includes.h"
+
+#include "drizzled/plugin_registry.h"
+#include "drizzled/plugin_registry_impl.h"
+
+#include <vector>
+
+using namespace std;
+
+
+static Plugin_registry the_registry;
+
+Plugin_registry::Plugin_registry()
+{
+  pImpl= new Plugin_registry_impl();
+}
+
+Plugin_registry& Plugin_registry::get_plugin_registry()
+{
+  return the_registry;
+}
+
+st_plugin_int *Plugin_registry::find(const LEX_STRING *name, int type)
+{
+  return pImpl->find(name, type);
+}
+
+void Plugin_registry::add(st_mysql_plugin *handle, st_plugin_int *plugin)
+{
+  pImpl->add(handle, plugin);
+}
+
+void Plugin_registry::get_mask_list(uint32_t type,
+                                    vector<st_plugin_int *> &plugins,
+                                    uint32_t state_mask)
+{
+  pImpl->get_mask_list(type, plugins, state_mask);
+}

=== added file 'drizzled/plugin_registry.h'
--- drizzled/plugin_registry.h	1970-01-01 00:00:00 +0000
+++ drizzled/plugin_registry.h	2009-03-03 01:59:29 +0000
@@ -0,0 +1,39 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2008 Sun Microsystems
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include <vector>
+
+class Plugin_registry_impl;
+
+class Plugin_registry
+{
+private:
+  Plugin_registry_impl *pImpl;
+public:
+  Plugin_registry();
+  static Plugin_registry& get_plugin_registry();
+  st_plugin_int *find(const LEX_STRING *name, int type);
+
+  void add(st_mysql_plugin *handle, st_plugin_int *plugin);
+  void get_mask_list(uint32_t type,
+                     std::vector<st_plugin_int *> &plugins,
+                     uint32_t state_mask);
+
+};
+

=== added file 'drizzled/plugin_registry_impl.cc'
--- drizzled/plugin_registry_impl.cc	1970-01-01 00:00:00 +0000
+++ drizzled/plugin_registry_impl.cc	2009-03-03 02:22:51 +0000
@@ -0,0 +1,81 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2008 Sun Microsystems
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "drizzled/server_includes.h"
+#include "drizzled/plugin_registry_impl.h"
+
+#include "drizzled/plugin.h"
+
+#include <string>
+#include <vector>
+#include <map>
+
+using namespace std;
+
+st_plugin_int *Plugin_registry_impl::find(const LEX_STRING *name, int type)
+{
+  uint32_t i;
+  string find_str(name->str,name->length);
+  transform(find_str.begin(), find_str.end(), find_str.begin(), ::tolower);
+
+  map<string, st_plugin_int *>::iterator map_iter;
+  if (type == DRIZZLE_ANY_PLUGIN)
+  {
+    for (i= 0; i < DRIZZLE_MAX_PLUGIN_TYPE_NUM; i++)
+    {
+      map_iter= plugin_map[i].find(find_str);
+      if (map_iter != plugin_map[i].end())
+        return (*map_iter).second;
+    }
+  }
+  else
+  {
+    map_iter= plugin_map[type].find(find_str);
+    if (map_iter != plugin_map[type].end())
+      return (*map_iter).second;
+  }
+  return(0);
+}
+
+void Plugin_registry_impl::add(st_mysql_plugin *handle, st_plugin_int *plugin)
+{
+  string add_str(plugin->name.str);
+  transform(add_str.begin(), add_str.end(),
+            add_str.begin(), ::tolower);
+
+  plugin_map[handle->type][add_str]= plugin;
+}
+
+
+void Plugin_registry_impl::get_mask_list(uint32_t type,
+                                         vector<st_plugin_int *> &plugins,
+                                         uint32_t state_mask)
+{
+  st_plugin_int *plugin= NULL;
+  plugins.reserve(plugin_map[type].size());
+  map<string, st_plugin_int *>::iterator map_iter;
+
+  for (map_iter= plugin_map[type].begin();
+       map_iter != plugin_map[type].end();
+       map_iter++)
+  {
+    plugin= (*map_iter).second;
+    plugins.push_back(!(plugin->state & state_mask) ? plugin : NULL);
+  }
+}

=== added file 'drizzled/plugin_registry_impl.h'
--- drizzled/plugin_registry_impl.h	1970-01-01 00:00:00 +0000
+++ drizzled/plugin_registry_impl.h	2009-03-03 01:59:29 +0000
@@ -0,0 +1,42 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2008 Sun Microsystems
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include <string>
+#include <vector>
+#include <map>
+
+class Plugin_registry_impl
+{
+private:
+  std::map<std::string, st_plugin_int *>
+    plugin_map[DRIZZLE_MAX_PLUGIN_TYPE_NUM];
+
+  Plugin_registry_impl(const Plugin_registry_impl&);
+public:
+  Plugin_registry_impl() {}
+
+  st_plugin_int *find(const LEX_STRING *name, int type);
+
+  void add(st_mysql_plugin *handle, st_plugin_int *plugin);
+
+  void get_mask_list(uint32_t type,
+                     std::vector<st_plugin_int *> &plugins,
+                     uint32_t state_mask);
+
+};

=== modified file 'drizzled/serialize/binlog_encoding.h'
--- drizzled/serialize/binlog_encoding.h	2008-11-12 17:42:40 +0000
+++ drizzled/serialize/binlog_encoding.h	2009-03-02 15:57:39 +0000
@@ -33,7 +33,7 @@
   unsigned char *ptr= buf;
   assert(length > 1);
   if (length < 256)
-    *ptr++= length & 0xFF;
+    *ptr++= (unsigned char) (length & 0xFF);
   else {
     int_fast8_t log2m1= -1;        // ceil(log2(ptr - buf)) - 1
     uint_fast8_t pow2= 1;          // pow2(log2m1 + 1)
@@ -45,7 +45,7 @@
       // Write the least significant byte of the current
       // length. Prefix increment is used to make space for the first
       // byte that will hold log2m1.
-      *++ptr= length & 0xFF;
+      *++ptr= (unsigned char)length & 0xFF;
       length >>= 8;
 
       // Ensure the invariant holds by correcting it if it doesn't,

=== modified file 'drizzled/sql_lex.cc'
--- drizzled/sql_lex.cc	2009-02-21 00:18:15 +0000
+++ drizzled/sql_lex.cc	2009-03-03 07:39:39 +0000
@@ -24,6 +24,9 @@
 #include <drizzled/sql_base.h>
 #include <drizzled/lookup_symbol.h>
 
+#include <ctype.h>
+
+using namespace std;
 
 
 static int lex_one_token(void *arg, void *yysession);
@@ -1115,31 +1118,28 @@
 
         /*
           The special comment format is very strict:
-          '/' '*' '!', followed by exactly
-          1 digit (major), 2 digits (minor), then 2 digits (dot).
-          32302 -> 3.23.02
-          50032 -> 5.0.32
-          50114 -> 5.1.14
+          '/' '*' '!', followed by digits ended by a non-digit.
+          There must be at least 5 digits for it to count
         */
-        char version_str[6];
-        version_str[0]= lip->yyPeekn(0);
-        version_str[1]= lip->yyPeekn(1);
-        version_str[2]= lip->yyPeekn(2);
-        version_str[3]= lip->yyPeekn(3);
-        version_str[4]= lip->yyPeekn(4);
-        version_str[5]= 0;
-        if (  my_isdigit(cs, version_str[0])
-           && my_isdigit(cs, version_str[1])
-           && my_isdigit(cs, version_str[2])
-           && my_isdigit(cs, version_str[3])
-           && my_isdigit(cs, version_str[4])
-           )
-        {
-          ulong version;
-          version=strtol(version_str, NULL, 10);
+        const int MAX_VERSION_SIZE= 16;
+        char version_str[MAX_VERSION_SIZE];
+
+        int pos= 0;
+        do
+        {
+          version_str[pos]= lip->yyPeekn(pos);
+          pos++;
+        } while ((pos < MAX_VERSION_SIZE-1) && isdigit(version_str[pos-1]));
+        version_str[pos]= 0;
+
+        /* To keep some semblance of compatibility, we impose a 5 digit floor */
+        if (pos > 4)
+        {
+          uint64_t version;
+          version=strtoll(version_str, NULL, 10);
 
           /* Accept 'M' 'm' 'm' 'd' 'd' */
-          lip->yySkipn(5);
+          lip->yySkipn(pos-1);
 
           if (version <= DRIZZLE_VERSION_ID)
           {

=== modified file 'drizzled/sql_plugin.cc'
--- drizzled/sql_plugin.cc	2009-02-21 05:34:53 +0000
+++ drizzled/sql_plugin.cc	2009-03-03 02:22:51 +0000
@@ -31,6 +31,7 @@
 #include <drizzled/set_var.h>
 #include <drizzled/session.h>
 #include <drizzled/item/null.h>
+#include <drizzled/plugin_registry.h>
 
 #include <string>
 #include <vector>
@@ -131,7 +132,7 @@
 
 static DYNAMIC_ARRAY plugin_dl_array;
 static DYNAMIC_ARRAY plugin_array;
-static map<string, st_plugin_int *> plugin_map[DRIZZLE_MAX_PLUGIN_TYPE_NUM];
+
 static bool reap_needed= false;
 static int plugin_array_version=0;
 
@@ -470,39 +471,18 @@
 }
 
 
-static struct st_plugin_int *plugin_find_internal(const LEX_STRING *name, int type)
-{
-  uint32_t i;
-  if (! initialized)
-    return(0);
-  string find_str(name->str,name->length);
-  transform(find_str.begin(), find_str.end(), find_str.begin(), ::tolower);
-
-  map<string, st_plugin_int *>::iterator map_iter;
-  if (type == DRIZZLE_ANY_PLUGIN)
-  {
-    for (i= 0; i < DRIZZLE_MAX_PLUGIN_TYPE_NUM; i++)
-    {
-      map_iter= plugin_map[i].find(find_str);
-      if (map_iter != plugin_map[i].end())
-        return (*map_iter).second;
-    }
-  }
-  else
-  {
-    map_iter= plugin_map[type].find(find_str);
-    if (map_iter != plugin_map[type].end())
-      return (*map_iter).second;
-  }
-  return(0);
-}
-
 
 static SHOW_COMP_OPTION plugin_status(const LEX_STRING *name, int type)
 {
+  Plugin_registry registry= Plugin_registry::get_plugin_registry();
+
   SHOW_COMP_OPTION rc= SHOW_OPTION_NO;
   struct st_plugin_int *plugin;
-  if ((plugin= plugin_find_internal(name, type)))
+
+  if (! initialized)
+    return(rc);
+
+  if ((plugin= registry.find(name, type)))
   {
     rc= SHOW_OPTION_DISABLED;
     if (plugin->state == PLUGIN_IS_READY)
@@ -563,10 +543,15 @@
 
 plugin_ref plugin_lock_by_name(Session *session, const LEX_STRING *name, int type)
 {
+  Plugin_registry registry= Plugin_registry::get_plugin_registry();
+
   LEX *lex= session ? session->lex : 0;
   plugin_ref rc= NULL;
   st_plugin_int *plugin;
-  if ((plugin= plugin_find_internal(name, type)))
+  if (! initialized)
+    return(0);
+
+  if ((plugin= registry.find(name, type)))
     rc= my_intern_plugin_lock_ci(lex, plugin_int_to_ref(plugin));
   return(rc);
 }
@@ -603,9 +588,14 @@
                        const LEX_STRING *name, const LEX_STRING *dl,
                        int *argc, char **argv, int report)
 {
+  Plugin_registry registry= Plugin_registry::get_plugin_registry();
+
   struct st_plugin_int tmp;
   struct st_mysql_plugin *plugin;
-  if (plugin_find_internal(name, DRIZZLE_ANY_PLUGIN))
+  if (! initialized)
+    return(0);
+
+  if (registry.find(name, DRIZZLE_ANY_PLUGIN))
   {
     if (report & REPORT_TO_USER)
       my_error(ER_UDF_EXISTS, MYF(0), name->str);
@@ -639,11 +629,7 @@
         if ((tmp_plugin_ptr= plugin_insert_or_reuse(&tmp)))
         {
           plugin_array_version++;
-          string add_str(plugin->name);
-          transform(add_str.begin(), add_str.end(),
-                    add_str.begin(), ::tolower);
-
-          plugin_map[plugin->type][add_str]= tmp_plugin_ptr;
+          registry.add(plugin, tmp_plugin_ptr);
           init_alloc_root(&tmp_plugin_ptr->mem_root, 4096, 4096);
           return(false);
         }
@@ -981,6 +967,8 @@
                              struct st_plugin_int **ptr)
 {
 
+  Plugin_registry registry= Plugin_registry::get_plugin_registry();
+
   tmp->state= PLUGIN_IS_UNINITIALIZED;
   tmp->ref_count= 0;
   tmp->plugin_dl= 0;
@@ -993,11 +981,7 @@
         (struct st_plugin_int *) memdup_root(&plugin_mem_root, (unsigned char*)tmp,
                                              sizeof(struct st_plugin_int));
 
-  string add_str(plugin->name);
-  transform(add_str.begin(), add_str.end(),
-            add_str.begin(), ::tolower);
-
-  plugin_map[plugin->type][add_str]= *ptr;
+  registry.add(plugin, *ptr);
 
   return(0);
 }
@@ -1234,16 +1218,8 @@
   }
   else
   {
-    plugins.reserve(plugin_map[type].size());
-    map<string, st_plugin_int *>::iterator map_iter;
-
-    for (map_iter= plugin_map[type].begin();
-         map_iter != plugin_map[type].end();
-         map_iter++)
-    {
-      plugin= (*map_iter).second;
-      plugins.push_back(!(plugin->state & state_mask) ? plugin : NULL);
-    }
+    Plugin_registry registry= Plugin_registry::get_plugin_registry();
+    registry.get_mask_list(type, plugins, state_mask);
   }
 
   vector<st_plugin_int *>::iterator plugin_iter;

=== modified file 'drizzled/table.cc'
--- drizzled/table.cc	2009-02-28 17:48:22 +0000
+++ drizzled/table.cc	2009-03-03 09:40:55 +0000
@@ -365,7 +365,6 @@
     break;
   case DRIZZLE_TYPE_NULL:
     return new Item_null();
-    break;
   case DRIZZLE_TYPE_TIMESTAMP:
   case DRIZZLE_TYPE_DATETIME:
   case DRIZZLE_TYPE_DATE:

=== modified file 'libdrizzleclient/errmsg.c'
--- libdrizzleclient/errmsg.c	2009-02-08 11:11:30 +0000
+++ libdrizzleclient/errmsg.c	2009-03-03 08:08:10 +0000
@@ -19,6 +19,7 @@
 
 /* Error messages for MySQL clients */
 
+#include "config.h"
 #include <drizzled/gettext.h>
 #include "errmsg.h"
 

=== added file 'm4/bzr_version.m4.in'
--- m4/bzr_version.m4.in	1970-01-01 00:00:00 +0000
+++ m4/bzr_version.m4.in	2009-03-02 23:14:32 +0000
@@ -0,0 +1,8 @@
+dnl We do this here, rather than in configure.ac, so that if it doesn't change
+dnl nothing has to be rebuilt or anything
+BZR_REVNO=@BZR_REVNO@
+BZR_REVID=@BZR_REVID@
+BZR_BRANCH=@BZR_BRANCH@
+RELEASE_DATE=@RELEASE_DATE@
+RELEASE_VERSION=@RELEASE_VERSION@
+AC_INIT([drizzle],[@RELEASE_VERSION@],[http://bugs.launchpad.net/drizzle])

=== modified file 'plugin/auth_pam/Makefile.am'
--- plugin/auth_pam/Makefile.am	2008-12-20 23:44:07 +0000
+++ plugin/auth_pam/Makefile.am	2009-03-02 15:57:39 +0000
@@ -17,6 +17,6 @@
 EXTRA_LTLIBRARIES =	libauth_pam.la
 pkgplugin_LTLIBRARIES =	@plugin_auth_pam_shared_target@
 libauth_pam_la_LDFLAGS =	-module -avoid-version -rpath $(pkgplugindir) -lpam 
-libauth_pam_la_CPPFLAGS=	$(GLOBAL_CPPFLAGS) -DDRIZZLE_DYNAMIC_PLUGIN
+libauth_pam_la_CPPFLAGS=	$(AM_CPPFLAGS) -DDRIZZLE_DYNAMIC_PLUGIN
 libauth_pam_la_SOURCES =	auth_pam.cc
 endif

=== modified file 'plugin/compress/Makefile.am'
--- plugin/compress/Makefile.am	2008-12-20 23:44:07 +0000
+++ plugin/compress/Makefile.am	2009-03-02 15:57:39 +0000
@@ -13,12 +13,11 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-AM_CPPFLAGS = 		${GLOBAL_CPPFLAGS} -I${top_srcdir}/drizzled
 EXTRA_LTLIBRARIES =	libcompressudf.la
 pkgplugin_LTLIBRARIES =	@plugin_compress_shared_target@
 libcompressudf_la_LDFLAGS =	-module -avoid-version -rpath $(pkgplugindir)\
-				${Z_LIBS}
-libcompressudf_la_CXXFLAGS=	$(AM_CXXFLAGS) -DDRIZZLE_DYNAMIC_PLUGIN
+				${LIBZ}
+libcompressudf_la_CPPFLAGS=	$(AM_CPPFLAGS) -DDRIZZLE_DYNAMIC_PLUGIN
 libcompressudf_la_SOURCES =	compressudf.cc
 
 

=== modified file 'plugin/crc32/Makefile.am'
--- plugin/crc32/Makefile.am	2009-02-08 08:24:51 +0000
+++ plugin/crc32/Makefile.am	2009-03-02 15:57:39 +0000
@@ -13,12 +13,11 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-AM_CPPFLAGS = 		${GLOBAL_CPPFLAGS} -I${top_srcdir}/drizzled
 EXTRA_LTLIBRARIES =	libcrc32udf.la
 pkgplugin_LTLIBRARIES =	@plugin_crc32_shared_target@
 libcrc32udf_la_LDFLAGS =	-module -avoid-version -rpath $(pkgplugindir)
 libcrc32udf_la_LIBADD =		$(LIBZ)
-libcrc32udf_la_CXXFLAGS=	$(AM_CXXFLAGS) -DDRIZZLE_DYNAMIC_PLUGIN
+libcrc32udf_la_CPPFLAGS=	$(AM_CPPFLAGS) -DDRIZZLE_DYNAMIC_PLUGIN
 libcrc32udf_la_SOURCES =	crc32udf.cc
 
 

=== modified file 'plugin/errmsg_stderr/Makefile.am'
--- plugin/errmsg_stderr/Makefile.am	2008-12-20 23:44:07 +0000
+++ plugin/errmsg_stderr/Makefile.am	2009-03-02 15:57:39 +0000
@@ -3,5 +3,5 @@
 EXTRA_LTLIBRARIES = liberrmsg_stderr.la
 pkgplugin_LTLIBRARIES =	@plugin_errmsg_stderr_shared_target@
 liberrmsg_stderr_la_LDFLAGS = -module -avoid-version -rpath $(pkgplugindir)
-liberrmsg_stderr_la_CPPFLAGS= $(GLOBAL_CPPFLAGS) -DDRIZZLE_DYNAMIC_PLUGIN
+liberrmsg_stderr_la_CPPFLAGS= $(AM_CPPFLAGS) -DDRIZZLE_DYNAMIC_PLUGIN
 liberrmsg_stderr_la_SOURCES = errmsg_stderr.cc

=== modified file 'plugin/logging_query/Makefile.am'
--- plugin/logging_query/Makefile.am	2009-01-27 23:50:20 +0000
+++ plugin/logging_query/Makefile.am	2009-03-02 15:57:39 +0000
@@ -1,7 +1,7 @@
 EXTRA_LTLIBRARIES = liblogging_query.la
 pkgplugin_LTLIBRARIES =	@plugin_logging_query_shared_target@
 liblogging_query_la_LDFLAGS = -module -avoid-version -rpath $(pkgplugindir)
-liblogging_query_la_CPPFLAGS = $(GLOBAL_CPPFLAGS) -DDRIZZLE_DYNAMIC_PLUGIN
+liblogging_query_la_CPPFLAGS = $(AM_CPPFLAGS) -DDRIZZLE_DYNAMIC_PLUGIN
 liblogging_query_la_SOURCES = logging_query.cc
 
 EXTRA_LIBRARIES = liblogging_query.a

=== modified file 'plugin/logging_syslog/Makefile.am'
--- plugin/logging_syslog/Makefile.am	2009-02-03 21:09:37 +0000
+++ plugin/logging_syslog/Makefile.am	2009-03-02 15:57:39 +0000
@@ -14,12 +14,11 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 
-
 noinst_HEADERS= names.h
 EXTRA_LTLIBRARIES = liblogging_syslog.la
 pkgplugin_LTLIBRARIES =	@plugin_logging_syslog_shared_target@
 liblogging_syslog_la_LDFLAGS = -module -avoid-version -rpath $(pkgplugindir)
-liblogging_syslog_la_CPPFLAGS = $(GLOBAL_CPPFLAGS) -DDRIZZLE_DYNAMIC_PLUGIN
+liblogging_syslog_la_CPPFLAGS = $(AM_CPPFLAGS) -DDRIZZLE_DYNAMIC_PLUGIN
 liblogging_syslog_la_SOURCES = logging_syslog.cc
 
 EXTRA_LIBRARIES = liblogging_syslog.a

=== modified file 'plugin/md5/Makefile.am'
--- plugin/md5/Makefile.am	2009-02-13 00:19:53 +0000
+++ plugin/md5/Makefile.am	2009-03-02 15:57:39 +0000
@@ -13,14 +13,14 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-AM_CPPFLAGS = ${GLOBAL_CPPFLAGS} $(SSL_CFLAGS)
+AM_CPPFLAGS += $(SSL_CFLAGS)
 
 if BUILD_MD5_UDF
 EXTRA_LTLIBRARIES=	libmd5udf.la
 pkgplugin_LTLIBRARIES=	@plugin_md5_shared_target@
 libmd5udf_la_LDFLAGS=	-module -avoid-version -rpath $(pkgplugindir)
 libmd5udf_la_LIBADD=	$(CRYPTO_LIBS)
-libmd5udf_la_CXXFLAGS=	${AM_CXXFLAGS} -DDRIZZLE_DYNAMIC_PLUGIN
+libmd5udf_la_CPPFLAGS=	${AM_CPPFLAGS} -DDRIZZLE_DYNAMIC_PLUGIN
 libmd5udf_la_SOURCES=	md5udf.cc
 
 EXTRA_LIBRARIES=	libmd5udf.a

=== modified file 'plugin/signal_handler/signal_handler.cc'
--- plugin/signal_handler/signal_handler.cc	2009-02-27 21:38:40 +0000
+++ plugin/signal_handler/signal_handler.cc	2009-03-03 09:40:55 +0000
@@ -96,6 +96,7 @@
 
 /** This threads handles all signals and alarms. */
 /* ARGSUSED */
+extern "C"
 pthread_handler_t signal_hand(void *)
 {
   sigset_t set;

=== modified file 'plugin/uncompress/Makefile.am'
--- plugin/uncompress/Makefile.am	2008-12-20 23:44:07 +0000
+++ plugin/uncompress/Makefile.am	2009-03-02 15:57:39 +0000
@@ -13,12 +13,11 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-AM_CPPFLAGS = 		${GLOBAL_CPPFLAGS} -I${top_srcdir}/drizzled
 EXTRA_LTLIBRARIES =	libuncompressudf.la
 pkgplugin_LTLIBRARIES =	@plugin_uncompress_shared_target@
 libuncompressudf_la_LDFLAGS =	-module -avoid-version -rpath $(pkgplugindir) \
-				${Z_LIBS}
-libuncompressudf_la_CXXFLAGS=	$(AM_CXXFLAGS) -DDRIZZLE_DYNAMIC_PLUGIN
+				${LIBZ}
+libuncompressudf_la_CPPFLAGS=	$(AM_CPPFLAGS) -DDRIZZLE_DYNAMIC_PLUGIN
 libuncompressudf_la_SOURCES =	uncompressudf.cc
 
 

=== modified file 'plugin/uncompressed_length/Makefile.am'
--- plugin/uncompressed_length/Makefile.am	2008-12-20 23:44:07 +0000
+++ plugin/uncompressed_length/Makefile.am	2009-03-02 15:57:39 +0000
@@ -13,7 +13,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-AM_CPPFLAGS = 		${GLOBAL_CPPFLAGS} -I${top_srcdir}/drizzled
 EXTRA_LTLIBRARIES =	libuncompressed_lengthudf.la
 pkgplugin_LTLIBRARIES =	@plugin_uncompressed_length_shared_target@
 libuncompressed_lengthudf_la_LDFLAGS =	-module -avoid-version -rpath $(pkgplugindir)

=== modified file 'storage/innobase/Makefile.am'
--- storage/innobase/Makefile.am	2009-01-30 04:45:55 +0000
+++ storage/innobase/Makefile.am	2009-03-03 05:34:04 +0000
@@ -14,11 +14,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 
-AM_CPPFLAGS=		-I$(top_srcdir) -I$(top_builddir) \
-			-I$(top_srcdir)/include -I$(top_builddir)/include \
-			-I$(top_srcdir)/regex \
-			-I$(top_srcdir)/storage/innobase/include \
-			-I$(top_srcdir)/sql
+AM_CPPFLAGS+=		-I$(top_srcdir)/storage/innobase/include
 
 if BUILD_DRIZZLE
 EXTRA_DEFS="-DBUILD_DRIZZLE"

=== modified file 'storage/innobase/plug.in'
--- storage/innobase/plug.in	2009-02-10 20:38:14 +0000
+++ storage/innobase/plug.in	2009-03-03 09:40:55 +0000
@@ -19,24 +19,24 @@
   AC_C_BIGENDIAN
   case "$target_os" in
          lin*)
-           AM_CFLAGS="$AM_CFLAGS -DUNIV_LINUX";;
+           CFLAGS="$CFLAGS -DUNIV_LINUX";;
          hpux10*)
-           AM_CFLAGS="$AM_CFLAGS -DUNIV_MUST_NOT_INLINE -DUNIV_HPUX -DUNIV_HPUX10";;
+           CFLAGS="$CFLAGS -DUNIV_MUST_NOT_INLINE -DUNIV_HPUX -DUNIV_HPUX10";;
          hp*)
-           AM_CFLAGS="$AM_CFLAGS -DUNIV_MUST_NOT_INLINE -DUNIV_HPUX";;
+           CFLAGS="$CFLAGS -DUNIV_MUST_NOT_INLINE -DUNIV_HPUX";;
          aix*)
-           AM_CFLAGS="$AM_CFLAGS -DUNIV_AIX";;
+           CFLAGS="$CFLAGS -DUNIV_AIX";;
          irix*)
-           AM_CFLAGS="$AM_CFLAGS -DUNIV_MUST_NOT_INLINE";;
+           CFLAGS="$CFLAGS -DUNIV_MUST_NOT_INLINE";;
          osf*)
-           AM_CFLAGS="$AM_CFLAGS -DUNIV_MUST_NOT_INLINE";;
+           CFLAGS="$CFLAGS -DUNIV_MUST_NOT_INLINE";;
 	 *solaris*|*SunOS*)
-           AM_CFLAGS="$AM_CFLAGS -DUNIV_SOLARIS";;
+           CFLAGS="$CFLAGS -DUNIV_SOLARIS";;
          sysv5uw7*)
            # Problem when linking on SCO
-           AM_CFLAGS="$AM_CFLAGS -DUNIV_MUST_NOT_INLINE";;
+           CFLAGS="$CFLAGS -DUNIV_MUST_NOT_INLINE";;
          openbsd*)
-           AM_CFLAGS="$AM_CFLAGS -DUNIV_MUST_NOT_INLINE";;
+           CFLAGS="$CFLAGS -DUNIV_MUST_NOT_INLINE";;
   esac
 
   AM_CONDITIONAL(BUILD_DRIZZLE,[test "x$ac_build_drizzle" = "xyes"])

=== modified file 'tests/r/comments.result'
--- tests/r/comments.result	2008-12-06 22:41:03 +0000
+++ tests/r/comments.result	2009-03-03 07:39:39 +0000
@@ -11,8 +11,8 @@
 1  +1
 2
 select 1 /*!72301 +1 */;
-1
-1
+1  +1
+2
 select 1--1;
 1--1
 2
@@ -29,10 +29,11 @@
 select 1/*!2*/;
 ERROR 42000: You have an error in your SQL syntax; check the manual that corresponds to your Drizzle server version for the right syntax to use near '2*/' at line 1
 select 1/*!000002*/;
-ERROR 42000: You have an error in your SQL syntax; check the manual that corresponds to your Drizzle server version for the right syntax to use near '2*/' at line 1
-select 1/*!999992*/;
-1
-1
-select 1 + /*!00000 2 */ + 3 /*!99999 noise*/ + 4;
+1
+1
+select 1/*!2038129999 2*/;
+1
+1
+select 1 + /*!00000 2 */ + 3 /*!2038129999 noise*/ + 4;
 1 +  2  + 3  + 4
 10

=== modified file 'tests/r/func_system.result'
--- tests/r/func_system.result	2009-02-17 10:00:38 +0000
+++ tests/r/func_system.result	2009-03-03 00:50:59 +0000
@@ -4,20 +4,11 @@
 select database() = "test";
 database() = "test"
 1
-select database() = "test";
-database() = "test"
-1
-select user() like "%@%";
-user() like "%@%"
-1
-select user() like "%@%";
-user() like "%@%"
-1
-select version()>="3.23.29";
-version()>="3.23.29"
-1
-select version()>="3.23.29";
-version()>="3.23.29"
+select user() like "%@%";
+user() like "%@%"
+1
+select version() > "2009.01.756";
+version() > "2009.01.756"
 1
 explain extended select database(), user();
 id	select_type	table	type	possible_keys	key	key_len	ref	rows	filtered	Extra

=== modified file 'tests/t/comments.test'
--- tests/t/comments.test	2008-12-06 22:41:03 +0000
+++ tests/t/comments.test	2009-03-03 07:39:39 +0000
@@ -27,9 +27,8 @@
 --error ER_PARSE_ERROR
 select 1/*!2*/;
 
---error ER_PARSE_ERROR
 select 1/*!000002*/;
 
-select 1/*!999992*/;
+select 1/*!2038129999 2*/;
 
-select 1 + /*!00000 2 */ + 3 /*!99999 noise*/ + 4;
+select 1 + /*!00000 2 */ + 3 /*!2038129999 noise*/ + 4;

=== modified file 'tests/t/func_system.test'
--- tests/t/func_system.test	2009-01-28 04:37:46 +0000
+++ tests/t/func_system.test	2009-03-03 00:50:59 +0000
@@ -4,13 +4,10 @@
 
 select database();
 select database() = "test";
-select database() = "test";
-
-select user() like "%@%";
-select user() like "%@%";
-
-select version()>="3.23.29";
-select version()>="3.23.29";
+
+select user() like "%@%";
+
+select version() > "2009.01.756";
 explain extended select database(), user();
 
 create table t1 (version char(60)) select database(), user(), version() as 'version';

